/**
 * Copyright (c) 2008 by The Shoe Shine Boy.
 * 
 * This file is part of JMS SMTP Bridge.
 * 
 * JMS SMTP Bridge is free software: you can redistribute it and/or modify it 
 * under the terms of the GNU General Public License as published by the 
 * Free Software Foundation, either version 3 of the License, or (at your 
 * option) any later version.
 *
 * JMS SMTP Bridge is distributed in the hope that it will be useful, but WITHOUT 
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License 
 * along with JMS SMTP Bridge. If not, see <http://www.gnu.org/licenses/>.
 */
package com.gt.jmsmtpbridge.transform;

import java.rmi.RemoteException;
import java.util.Enumeration;
import java.util.Hashtable;

import javax.jms.JMSException;
import javax.jms.MapMessage;
import javax.jms.Message;

import org.apache.log4j.Logger;

/**
 * One of the sample implementations of Jms2SmtpTransformerBean Session Bean.
 * 
 * This class has been provided as a sample to show how to implement the transformation 
 * logic and how to transform a JMS MapMessage into a hashtable of name/value pairs 
 * that will be later read by the SmtpSender Bean to send mail(s).
 * 
 * @author The Shoe Shine Boy
 *
 */
@SuppressWarnings("serial")
public class MapMsgTransformerBean extends Jms2SmtpTransformerBean {
	// The logger
	private Logger m_logger = Logger.getLogger(getClass().getName());

	/**
	 * The transform() method.
	 * 
	 * Here this method simply loads all the MapMessage properties into a hashtable and 
	 * return that to the calling method.
	 * 
	 * Basically the MapMessage should have the following name/value pairs set:
	 * MAIL.TO			Required		The comma separated list of recipients in the to field
	 * MAIL.CC			Optional		The comma separated list of recipients in the cc field
	 * MAIL.BCC			Optional		The comma separated list of recipients in the bcc field
	 * MAIL.SUBJECT		Required		The subject line
	 * MAIL.BODY		Required		The mail body
	 * MAIL.SENDASHTML	Optional		The flag (true/false) telling if the mail needs to be 
	 * 									sent as html or plain/text 
	 */
	@SuppressWarnings("unchecked")
	@Override
	public Hashtable<String, Object> transform(Message msg)
			throws RemoteException {
		m_logger.info("Inside transform().");
		if (msg instanceof MapMessage) {
			try {
				MapMessage m = (MapMessage)msg;

				m_logger.debug("Loading message properties into hashtable...");
				Enumeration<String> keys = m.getMapNames();
				Hashtable<String, Object> hash = new Hashtable<String, Object>();
				while (keys.hasMoreElements()) {
					String key = keys.nextElement();
					hash.put(key, m.getObject(key));
				}
				
				m_logger.debug("Returning hash...");
				return hash;
			} catch (JMSException e) {
				throw new RemoteException(e.getMessage());
			}
		} else {
			throw new RemoteException("Expected MapMessage but received " + msg.getClass().getName());
		}
	}

}
