/**
 * Copyright (c) 2008 by The Shoe Shine Boy.
 * 
 * This file is part of JMS SMTP Bridge.
 * 
 * JMS SMTP Bridge is free software: you can redistribute it and/or modify it 
 * under the terms of the GNU General Public License as published by the 
 * Free Software Foundation, either version 3 of the License, or (at your 
 * option) any later version.
 *
 * JMS SMTP Bridge is distributed in the hope that it will be useful, but WITHOUT 
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License 
 * along with JMS SMTP Bridge. If not, see <http://www.gnu.org/licenses/>.
 */
package com.gt.test;

import java.util.Properties;

import javax.jms.Connection;
import javax.jms.ConnectionFactory;
import javax.jms.MapMessage;
import javax.jms.MessageProducer;
import javax.jms.Queue;
import javax.jms.Session;
import javax.naming.Context;
import javax.naming.InitialContext;

import com.gt.jmsmtpbridge.transform.Jms2SmtpTransformer;

/**
 * A sample stand-alone class to send a MapMessage so that it will be picked up by the JmsMessageReceiver 
 * MDB and eventually a mail would be sent out.
 * 
 * This class assumes that the MDB is listening on a queue named 'queue/JmsSmtpBridge-JmsReceiver' which 
 * resides in a local JBoss server. 
 * The important configuration parameters henceforth are:
 * Context.INITIAL_CONTEXT_FACTORY	org.jnp.interfaces.NamingContextFactory
 * Context.URL_PKG_PREFIXES			org.jboss.naming:org.jnp.interfaces
 * Context.PROVIDER_URL				jnp://localhost:1099
 *  
 * @author The Shoe Shine Boy
 *
 */
public class MapMsgSender {

	public static void main(String[] args) throws Exception {
		System.out.println("Start");
		Properties objProperties = new Properties();
		objProperties.put(Context.INITIAL_CONTEXT_FACTORY,"org.jnp.interfaces.NamingContextFactory");
		objProperties.put(Context.URL_PKG_PREFIXES, "org.jboss.naming:org.jnp.interfaces");
		objProperties.put(Context.PROVIDER_URL,"jnp://localhost:1099");
		InitialContext ctx = new InitialContext(objProperties);

		System.out.println("Looking up for the queue...");
		Queue q = (Queue)ctx.lookup("queue/JmsSmtpBridge-JmsReceiver");
		
		ConnectionFactory cf = (ConnectionFactory)ctx.lookup("QueueConnectionFactory");
		Connection c = cf.createConnection();
		Session s = c.createSession(false, Session.AUTO_ACKNOWLEDGE);
		
		MessageProducer sender = s.createProducer(q);
		
		MapMessage m = s.createMapMessage();
		m.setObject(Jms2SmtpTransformer.MAIL_TO, "customer1@abc.com");
		m.setObject(Jms2SmtpTransformer.MAIL_CC, "customer2@abc.com");
		m.setObject(Jms2SmtpTransformer.MAIL_SUBJECT, "a test message");
		m.setObject(Jms2SmtpTransformer.MAIL_BODY, "a test message body");
		m.setObject(Jms2SmtpTransformer.MAIL_SENDASHTML, Boolean.FALSE);
		
		System.out.println("Sending message...");
		sender.send(m);
		System.out.println("End");
	}
}
